@@ -52,7 +52,7 @@ class Demo():
         frame = HtmlFrame(root)
 
         frame.on_title_change(self.change_title)
-        frame.load_website("http://tkhtml.tcl.tk")
+        frame.load_website("https://wiki.python.org/moin/TkInter")
 
         frame.pack(expand=True, fill="both")
         root.mainloop()
